==> vtiger-4.0p1_1.tbz: www/vtiger/modules/System/includes/lang/fi.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: fi.php,v 1.1 2005/03/14 07:42:10 shankarr Exp $

// Finnish language file by Jani 'Japala' Ponkko

$text['title']          = 'Tietoa j&auml;rjestelm&auml;st&auml;';

$text['vitals']         = 'Perustiedot';
$text['hostname']       = 'Kanoninen nimi';
$text['ip']             = 'K&auml;ytett&auml;v&auml; IP';
$text['kversion']       = 'Kernelin versio';
$text['dversion']       = 'Distro Name';
$text['uptime']         = 'Toiminta-aika';
$text['users']          = 'K&auml;ytt&auml;ji&auml;';
$text['loadavg']        = 'Keskikuormat';

$text['hardware']       = 'Laitteisto';
$text['numcpu']         = 'Prosessoreita';
$text['cpumodel']       = 'Malli';
$text['mhz']            = 'Piirin MHz';
$text['cache']          = 'V&auml;limuistin koko';
$text['bogomips']       = 'J&auml;rjestelm&auml;n Bogomipsit';
$text['usb']            = 'USB Laitteet';
$text['pci']            = 'PCI Laitteet';
$text['ide']            = 'IDE Laitteet';
$text['scsi']           = 'SCSI Laitteet';

$text['netusage']       = 'Verkon k&auml;ytt&ouml;';
$text['device']         = 'Laite';
$text['received']       = 'Vastaanotettu';
$text['sent']           = 'L&auml;hetetty';
$text['errors']         = 'Virheet/Pudotetut';

$text['memusage']       = 'Muistin kuormitus';
$text['phymem']         = 'Fyysinen muisti';
$text['swap']           = 'Virtuaalimuisti';

$text['fs']             = 'Liitetyt tiedostoj&auml;rjestelm&auml;t';
$text['mount']          = 'Liitoskohta';
$text['partition']      = 'Osio';

$text['percent']        = 'Prosenttia kapasiteetista';
$text['type']           = 'Tyyppi';
$text['free']           = 'Vapaana';
$text['used']           = 'K&auml;yt&ouml;ss&auml;';
$text['size']           = 'Koko';
$text['totals']         = 'Yhteens&auml;';

$text['kb']             = 'KB';
$text['mb']             = 'MB';
$text['gb']             = 'GB';

$text['none']           = 'Ei yht&auml;&auml;n';

$text['capacity']       = 'Kapasiteetti'; 

$text['template']       = 'Malli';
$text['language']       = 'Kieli';
$text['submit']         = 'Valitse';
$text['created']        = 'Luonut';
$text['locale']         = 'en_US';
$text['gen_time']       = 'on %b %d, %Y at %r';

$text['days']           = 'p&auml;iv&auml;&auml;';
$text['hours']          = 'tuntia';
$text['minutes']        = 'minuuttia';
  
$text['temperature']    = 'Temperature';
$text['voltage']        = 'Voltage';
$text['fans']           = 'Fans';
$text['s_value']        = 'Value';
$text['s_min']          = 'Min';
$text['s_max']          = 'Max';
$text['s_div']          = 'Div';
$text['hysteresis']     = 'Hysteresis';
$text['s_limit']        = 'Limit';
$text['s_label']        = 'Label';
$text['degree_mark']    = '&ordm;C';
$text['voltage_mark']   = 'V';
$text['rpm_mark']       = 'RPM';

?>

==> vtiger-4.2.4.tbz: www/vtiger/modules/System/includes/lang/fi.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: fi.php,v 1.10 2004/08/30 15:51:26 webbie Exp $

// Finnish language file by Jani 'Japala' Ponkko

$text['title']          = 'Tietoa j&auml;rjestelm&auml;st&auml;';

$text['vitals']         = 'Perustiedot';
$text['hostname']       = 'Kanoninen nimi';
$text['ip']             = 'K&auml;ytett&auml;v&auml; IP';
$text['kversion']       = 'Kernelin versio';
$text['dversion']       = 'Distro Name';
$text['uptime']         = 'Toiminta-aika';
$text['users']          = 'K&auml;ytt&auml;ji&auml;';
$text['loadavg']        = 'Keskikuormat';

$text['hardware']       = 'Laitteisto';
$text['numcpu']         = 'Prosessoreita';
$text['cpumodel']       = 'Malli';
$text['cpuspeed']       = 'Piirin MHz';
$text['busspeed']       = 'BUS Speed';
$text['cache']          = 'V&auml;limuistin koko';
$text['bogomips']       = 'J&auml;rjestelm&auml;n Bogomipsit';

$text['pci']            = 'PCI Laitteet';
$text['ide']            = 'IDE Laitteet';
$text['scsi']           = 'SCSI Laitteet';
$text['usb']            = 'USB Laitteet';

$text['netusage']       = 'Verkon k&auml;ytt&ouml;';
$text['device']         = 'Laite';
$text['received']       = 'Vastaanotettu';
$text['sent']           = 'L&auml;hetetty';
$text['errors']         = 'Virheet/Pudotetut';

$text['memusage']       = 'Muistin kuormitus';
$text['phymem']         = 'Fyysinen muisti';
$text['swap']           = 'Virtuaalimuisti';

$text['fs']             = 'Liitetyt tiedostoj&auml;rjestelm&auml;t';
$text['mount']          = 'Liitoskohta';
$text['partition']      = 'Osio';

$text['percent']        = 'Prosenttia kapasiteetista';
$text['type']           = 'Tyyppi';
$text['free']           = 'Vapaana';
$text['used']           = 'K&auml;yt&ouml;ss&auml;';
$text['size']           = 'Koko';
$text['totals']         = 'Yhteens&auml;';

$text['kb']             = 'KB';
$text['mb']             = 'MB';
$text['gb']             = 'GB';

$text['none']           = 'Ei yht&auml;&auml;n';

$text['capacity']       = 'Kapasiteetti'; 

$text['template']       = 'Malli';
$text['language']       = 'Kieli';
$text['submit']         = 'Valitse';
$text['created']        = 'Luonut';
$text['locale']         = 'en_US';
$text['gen_time']       = 'on %b %d, %Y at %r';

$text['days']           = 'p&auml;iv&auml;&auml;';
$text['hours']          = 'tuntia';
$text['minutes']        = 'minuuttia';
  
$text['temperature']    = 'Temperature';
$text['voltage']        = 'Voltage';
$text['fans']           = 'Fans';
$text['s_value']        = 'Value';
$text['s_min']          = 'Min';
$text['s_max']          = 'Max';
$text['s_div']          = 'Div';
$text['hysteresis']     = 'Hysteresis';
$text['s_limit']        = 'Limit';
$text['s_label']        = 'Label';
$text['degree_mark']    = '&ordm;C';
$text['voltage_mark']   = 'V';
$text['rpm_mark']       = 'RPM';

?>
